@@ -5,7 +5,7 @@ from typing import Any, Callable, ClassVar, Generic, Protocol
 from urllib.parse import unquote, urldefrag, urljoin
 
 from attrs import evolve, field
-from pyrsistent import m, plist, pmap, s
+from pyrsistent import PMap as PMapType, plist, pmap, s
 from pyrsistent.typing import PList, PMap, PSet
 
 from referencing import exceptions
@@ -183,11 +183,14 @@ class Resource(Generic[D]):
                 raise exceptions.PointerToNowhere(ref=pointer, resource=self)
 
             segments.append(segment)
+            last = resolver
             resolver = self._specification.maybe_in_subresource(
                 segments=segments,
                 resolver=resolver,
                 subresource=self._specification.create_resource(contents),  # type: ignore[reportUnknownArgumentType]  # noqa: E501
             )
+            if resolver is not last:
+                segments = []
         return Resolved(contents=contents, resolver=resolver)  # type: ignore[reportUnknownArgumentType]  # noqa: E501
 
 
@@ -195,6 +198,14 @@ def _fail_to_retrieve(uri: URI):
     raise exceptions.NoSuchResource(ref=uri)
 
 
+def _to_pmap(
+    value: dict[URI, Resource[D]]
+    | PMap[URI, Resource[D]]
+    | list[tuple[URI, Resource[D]]],
+):
+    return value if isinstance(value, PMapType) else pmap(value)
+
+
 @frozen
 class Registry(Mapping[URI, Resource[D]]):
     r"""
@@ -219,8 +230,11 @@ class Registry(Mapping[URI, Resource[D]]):
     exception indicating that the resource is not retrievable.
     """
 
-    _resources: PMap[URI, Resource[D]] = field(default=m(), converter=pmap)  # type: ignore[reportUnknownArgumentType]  # noqa: E501
-    _anchors: PMap[tuple[URI, str], AnchorType[D]] = field(default=m())  # type: ignore[reportUnknownArgumentType]  # noqa: E501
+    _resources: PMap[URI, Resource[D]] = field(
+        default=pmap(),  # type: ignore[reportUnknownArgumentType]
+        converter=_to_pmap,
+    )
+    _anchors: PMap[tuple[URI, str], AnchorType[D]] = field(default=pmap())  # type: ignore[reportUnknownArgumentType]  # noqa: E501
     _uncrawled: PSet[URI] = field(default=s())  # type: ignore[reportUnknownArgumentType]  # noqa: E501
     _retrieve: Callable[[URI], Resource[D]] = field(default=_fail_to_retrieve)
 
